@@ -29,19 +29,6 @@
 # @keyword methods
 #*/###########################################################################
 setMethodS3("getMethodS3", "default", function(name, class="default", envir=parent.frame(), ...) {
-  args <- list(name, class=class, optional=FALSE);
-  do.call(getS3method, args, envir=envir);
+  args <- list(name, class=class, optional=FALSE)
+  do.call(getS3method, args, envir=envir)
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2011-11-17
-# o CLEANUP: Dropped example(getMethodS3), which was for setMethodS3().
-# 2010-09-18
-# o BUG FIX: getMethodS3() failed to locate S3 methods created in the
-#   global enviroment.
-# 2008-05-08
-# o Added getMethodS3().
-############################################################################
