@@ -1,4 +1,13 @@
 ## covr: skip=all
+.onLoad <- function(libname, pkgname) {
+  value <- getOption("R.methodsS3:useSearchPath", NULL)
+  if (is.null(value)) {
+    value <- Sys.getenv("R_R_METHODSS3_USE_SEARCH_PATH", "TRUE")
+    value <- isTRUE(as.logical(value))
+    options("R.methodsS3:useSearchPath" = value)
+  }
+}
+
 
 .onAttach <- function(libname, pkgname) {
   pd <- utils::packageDescription(pkgname)
